#
# spec file for package python-Pillow
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if ! 0%{?is_opensuse} && 0%{?sle_version} && 0%{sle_version} < 150000
%bcond_with tk
%else
%bcond_without tk
%endif

%define oldpython python
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Pillow
Version:        4.1.0
Release:        0
Summary:        Python Imaging Library (Fork)
License:        HPND
Group:          Development/Languages/Python
Url:            http://python-imaging.github.io/
Source:         https://files.pythonhosted.org/packages/source/P/Pillow/Pillow-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module olefile}
BuildRequires:  %{python_module setuptools}
%if %{with tk}
BuildRequires:  %{python_module tk}
%endif
BuildRequires:  fdupes
BuildRequires:  freetype2-devel
BuildRequires:  libtiff-devel
BuildRequires:  python-rpm-macros
BuildRequires:  tix
BuildRequires:  tk-devel
BuildRequires:  unzip
BuildRequires:  zlib-devel
Requires:       python-olefile
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1210
BuildRequires:  libjpeg8-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libwebp-devel
%else
%if 0%{?rhel} > 6
BuildRequires:  lcms2-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libwebp-devel
%else
BuildRequires:  %{python_module unittest2}
%endif
%endif
%if 0%{?suse_version} > 1315
BuildRequires:  openjpeg2-devel
%endif
%ifpython2
# Pillow is a friendly PIL fork which we used to package as 'imaging'
# Without providing python-imaging, all packages requiring it will break
Obsoletes:      %{oldpython}-imaging < %{version}
Provides:       %{oldpython}-imaging = %{version}
Obsoletes:      %{oldpython}-imaging-sane < %{version}
Provides:       %{oldpython}-imaging-sane = %{version}
%endif
%ifpython3
Obsoletes:      python3-imaging < %{version}
Provides:       python3-imaging = %{version}
%endif
%python_subpackages

%description
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

%package tk
Summary:        Python Imaging Library (Fork) - Tcl/Tk Module
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Requires:       python-tk
%ifpython2
# NOTE: We don't need to conflict with python-imaging here,
# because this package depends on python-Pillow, which already conflicts with python-imaging,
# so this cannot be installed alongside python-imaging
# And we cannot conflict with python-imaging directly, since python-Pillow provides python-imaging
# Just in case, conflict with python-imaging-tk in case it is ever implemented.
Obsoletes:      %{oldpython}-imaging-tk < %{version}
Provides:       %{oldpython}-imaging-tk = %{version}
%endif

%description tk
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

#NOTE(saschpe): No 'sane' subpackage like "python-imaging", that stuff
# would belong into python-pysane, if anybody would care :-)

%prep
%setup -q -n Pillow-%{version}

%build
%python_build

%install
%python_install
for p in pilconvert pildriver pilfile pilfont pilprint  createfontdatachunk enhancer explode gifmaker painter player thresholder viewer; do
  # retain old alternative-based names
  mv %{buildroot}%{_bindir}/$p.py %{buildroot}%{_bindir}/$p
done

%fdupes %{buildroot}%{_prefix}
# add missing path
%{python_expand echo "PIL" > %{buildroot}%{$python_sitearch}/PIL.pth}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
%ifarch ppc ppc64 s390 s390x
$python selftest.py --installed || \
echo "WARNING ignore failure https://github.com/python-pillow/Pillow/issues/1204"
$python test-installed.py  || \
echo "WARNING ignore failure https://github.com/python-pillow/Pillow/issues/1204"
%else
$python selftest.py --installed
$python test-installed.py
%endif
}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst LICENSE
%python3_only %{_bindir}/pilconvert
%python3_only %{_bindir}/pildriver
%python3_only %{_bindir}/pilfile
%python3_only %{_bindir}/pilfont
%python3_only %{_bindir}/pilprint
%python3_only %{_bindir}/createfontdatachunk
%python3_only %{_bindir}/enhancer
%python3_only %{_bindir}/explode
%python3_only %{_bindir}/gifmaker
%python3_only %{_bindir}/painter
%python3_only %{_bindir}/player
%python3_only %{_bindir}/thresholder
%python3_only %{_bindir}/viewer
%{python_sitearch}/PIL
%{python_sitearch}/PIL.pth
%{python_sitearch}/Pillow-%{version}-py%{python_version}.egg-info
%if 0%{?is_opensuse}
%exclude %{python_sitearch}/PIL/ImageTk*
%exclude %{python_sitearch}/PIL/_imagingtk*
%pycache_only %exclude %{python_sitearch}/PIL/__pycache__/ImageTk.*
%endif

%if %{with tk}

%files %{python_files tk}
%defattr(-,root,root,-)
%{python_sitearch}/PIL/ImageTk*
%{python_sitearch}/PIL/_imagingtk*
%pycache_only %{python_sitearch}/PIL/__pycache__/ImageTk.*

%endif

%changelog
